@@ -8,9 +8,8 @@ from typing import Union, List, Dict, Any, Callable
 import chess
 
 from chess_engines.parser import parser
-from chess_engines.Engines import __file__ as _engines_path
 
-_engines_path = os.path.dirname(_engines_path)
+_engines_path = 'Engines'
 
 
 class UciProtocol:
